==> alloy-forgery-fabric-3.0.3%2B1.21.10-sources.jar: io/wispforest/alloyforgery/compat/emi/CustomTextWidget.java <==
package io.wispforest.alloyforgery.compat.emi;

import dev.emi.emi.api.widget.*;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_5481;
import org.joml.Matrix3x2fStack;

public class CustomTextWidget extends Widget {
    private static final class_310 CLIENT = class_310.method_1551();
    private class_5481 text;
    private final int x, y;
    private final int color;
    private final boolean shadow;

    public CustomTextWidget(class_5481 text, int x, int y, int color, boolean shadow) {
        this.text = text;
        this.x = x;
        this.y = y;
        this.color = color;
        this.shadow = shadow;
    }

    public void setText(class_5481 text) {
        this.text = text;
    }

    @Override
    public Bounds getBounds() {
        int width = CLIENT.field_1772.method_30880(text);
        int xOff = TextWidget.Alignment.START.offset(width);
        int yOff = TextWidget.Alignment.START.offset(CLIENT.field_1772.field_2000);
        return new Bounds(x + xOff, y + yOff, width, CLIENT.field_1772.field_2000);
    }

    @Override
    public void method_25394(class_332 context, int mouseX, int mouseY, float delta) {
        var matrices = context.method_51448();
        matrices.pushMatrix();
        int xOff = TextWidget.Alignment.START.offset(CLIENT.field_1772.method_30880(text));
        int yOff = TextWidget.Alignment.START.offset(CLIENT.field_1772.field_2000);
        matrices.translate(xOff, yOff);
        context.method_51430(CLIENT.field_1772, text, x, y, color, shadow);
        matrices.popMatrix();
    }

}

==> alloy-forgery-fabric-3.0.6%2B1.21.4-sources.jar: io/wispforest/alloyforgery/compat/emi/CustomTextWidget.java <==
package io.wispforest.alloyforgery.compat.emi;

import dev.emi.emi.api.widget.*;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_4587;
import net.minecraft.class_5481;

public class CustomTextWidget extends Widget {
    private static final class_310 CLIENT = class_310.method_1551();
    private class_5481 text;
    private final int x, y;
    private final int color;
    private final boolean shadow;

    public CustomTextWidget(class_5481 text, int x, int y, int color, boolean shadow) {
        this.text = text;
        this.x = x;
        this.y = y;
        this.color = color;
        this.shadow = shadow;
    }

    public void setText(class_5481 text) {
        this.text = text;
    }

    @Override
    public Bounds getBounds() {
        int width = CLIENT.field_1772.method_30880(text);
        int xOff = TextWidget.Alignment.START.offset(width);
        int yOff = TextWidget.Alignment.START.offset(CLIENT.field_1772.field_2000);
        return new Bounds(x + xOff, y + yOff, width, CLIENT.field_1772.field_2000);
    }

    @Override
    public void method_25394(class_332 context, int mouseX, int mouseY, float delta) {
        var matrices = context.method_51448();
        matrices.method_22903();
        int xOff = TextWidget.Alignment.START.offset(CLIENT.field_1772.method_30880(text));
        int yOff = TextWidget.Alignment.START.offset(CLIENT.field_1772.field_2000);
        matrices.method_46416(xOff, yOff, 300);
        context.method_51430(CLIENT.field_1772, text, x, y, color, shadow);
        matrices.method_22909();
    }

}
